TrainingState

Trait TrainingState 

pub trait TrainingState { }
Marker trait for Orphos training state.

This trait is used in the type-state pattern to enforce that training must be performed before gene prediction. It’s implemented by both Untrained and Trained marker types.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors